@@ -15,13 +15,11 @@ def register():
         Product,
         PurchaseRequest,
         CreatePurchaseRequestStart,
-        CreatePurchaseAskParty,
         ShipmentInternal,
         CreateShipmentInternalStart,
         Location,
         module='stock_supply', type_='model')
     Pool.register(
         CreatePurchaseRequest,
-        CreatePurchase,
         CreateShipmentInternal,
         module='stock_supply', type_='wizard')
