@@ -45,7 +45,7 @@ class OrderPoint(ModelSQL, ModelView):
             'get_location', searcher='search_location')
     provisioning_location = fields.Many2One(
         'stock.location', 'Provisioning Location',
-        domain=[('type', '=', 'storage')],
+        domain=[('type', 'in', ['storage', 'view'])],
         states={
             'invisible': Not(Equal(Eval('type'), 'internal')),
             'required': Equal(Eval('type'), 'internal'),
@@ -88,9 +88,8 @@ class OrderPoint(ModelSQL, ModelView):
     @classmethod
     def __register__(cls, module_name):
         TableHandler = backend.get('TableHandler')
-        cursor = Transaction().cursor
         # Migration from 2.2
-        table = TableHandler(cursor, cls, module_name)
+        table = TableHandler(cls, module_name)
         table.drop_constraint('check_min_max_quantity')
 
         super(OrderPoint, cls).__register__(module_name)
