@@ -6,11 +6,10 @@ from sql.functions import Overlay, Position
 from trytond.model import ModelView, ModelSQL
 from trytond.wizard import Wizard, StateView, StateAction, Button
 from trytond.transaction import Transaction
-from trytond.pool import Pool, PoolMeta
+from trytond.pool import Pool
 
 __all__ = ['ShipmentInternal',
     'CreateShipmentInternalStart', 'CreateShipmentInternal']
-__metaclass__ = PoolMeta
 
 
 class ShipmentInternal(ModelSQL, ModelView):
@@ -18,7 +17,7 @@ class ShipmentInternal(ModelSQL, ModelView):
 
     @classmethod
     def __register__(cls, module_name):
-        cursor = Transaction().cursor
+        cursor = Transaction().connection.cursor()
         model_data = Table('ir_model_data')
         model = Table('ir_model')
         # Migration from 1.2: packing renamed into shipment
